"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Activates Shield Advanced for an account. When you initally create a subscription, your subscription is set to be automatically renewed at the end of the existing subscription period. You can change this by submitting an UpdateSubscription request.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.shield.subscription.init.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.shield.subscription.init.create
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="shield", operation="create_subscription", op_kwargs={}
    )


async def delete(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Removes Shield Advanced from an account. Shield Advanced requires a 1-year subscription commitment. You cannot delete a subscription prior to the completion of that commitment.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.shield.subscription.init.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.shield.subscription.init.delete
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="shield", operation="delete_subscription", op_kwargs={}
    )


async def describe(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Provides details about the Shield Advanced subscription for an account.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.shield.subscription.init.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.shield.subscription.init.describe
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="shield", operation="describe_subscription", op_kwargs={}
    )


async def update(hub, ctx, auto_renew: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates the details of an existing subscription. Only enter values for parameters you want to change. Empty parameters are not updated.

    Args:
        auto_renew(str, optional): When you initally create a subscription, AutoRenew is set to ENABLED. If ENABLED, the subscription will be automatically renewed at the end of the existing subscription period. You can change this by submitting an UpdateSubscription request. If the UpdateSubscription request does not included a value for AutoRenew, the existing value for AutoRenew remains unchanged. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.shield.subscription.init.update(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.shield.subscription.init.update
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="shield",
        operation="update_subscription",
        op_kwargs={"AutoRenew": auto_renew},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(
    hub, ctx, hosted_zone_id: str, vpc: Dict, comment: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Associates an Amazon VPC with a private hosted zone.   To perform the association, the VPC and the private hosted zone must already exist. You can't convert a public hosted zone into a private hosted zone.   If you want to associate a VPC that was created by using one account with a private hosted zone that was created by using a different account, the account that created the private hosted zone must first submit a CreateVPCAssociationAuthorization request. Then the account that created the VPC must submit an AssociateVPCWithHostedZone request.

    Args:
        hosted_zone_id(str): The ID of the private hosted zone that you want to associate an Amazon VPC with. Note that you can't associate a VPC with a hosted zone that doesn't have an existing VPC association.
        vpc(Dict): A complex type that contains information about the VPC that you want to associate with a private hosted zone.
        comment(str, optional):  Optional: A comment about the association request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.vpc.with_hosted_zone.associate(
                ctx, hosted_zone_id=value, vpc=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.vpc.with_hosted_zone.associate hosted_zone_id=value, vpc=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="associate_vpc_with_hosted_zone",
        op_kwargs={"HostedZoneId": hosted_zone_id, "VPC": vpc, "Comment": comment},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    global_network_id: str,
    aws_location: Dict = None,
    description: str = None,
    type_: str = None,
    vendor: str = None,
    model: str = None,
    serial_number: str = None,
    location: Dict = None,
    site_id: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new device in a global network. If you specify both a site ID and a location, the location of the site is used for visualization in the Network Manager console.

    Args:
        global_network_id(str): The ID of the global network.
        aws_location(Dict, optional): The AWS location of the device. Defaults to None.
        description(str, optional): A description of the device. Length Constraints: Maximum length of 256 characters. Defaults to None.
        type_(str, optional): The type of the device. Defaults to None.
        vendor(str, optional): The vendor of the device. Length Constraints: Maximum length of 128 characters. Defaults to None.
        model(str, optional): The model of the device. Length Constraints: Maximum length of 128 characters. Defaults to None.
        serial_number(str, optional): The serial number of the device. Length Constraints: Maximum length of 128 characters. Defaults to None.
        location(Dict, optional): The location of the device. Defaults to None.
        site_id(str, optional): The ID of the site. Defaults to None.
        tags(List, optional): The tags to apply to the resource during creation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.networkmanager.device.create(ctx, global_network_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.networkmanager.device.create global_network_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="networkmanager",
        operation="create_device",
        op_kwargs={
            "GlobalNetworkId": global_network_id,
            "AWSLocation": aws_location,
            "Description": description,
            "Type": type_,
            "Vendor": vendor,
            "Model": model,
            "SerialNumber": serial_number,
            "Location": location,
            "SiteId": site_id,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, global_network_id: str, device_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an existing device. You must first disassociate the device from any links and customer gateways.

    Args:
        global_network_id(str): The ID of the global network.
        device_id(str): The ID of the device.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.networkmanager.device.delete(
                ctx, global_network_id=value, device_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.networkmanager.device.delete global_network_id=value, device_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="networkmanager",
        operation="delete_device",
        op_kwargs={"GlobalNetworkId": global_network_id, "DeviceId": device_id},
    )


async def get_all(
    hub,
    ctx,
    global_network_id: str,
    device_ids: List = None,
    site_id: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about one or more of your devices in a global network.

    Args:
        global_network_id(str): The ID of the global network.
        device_ids(List, optional): One or more device IDs. The maximum is 10. Defaults to None.
        site_id(str, optional): The ID of the site. Defaults to None.
        max_results(int, optional): The maximum number of results to return. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.networkmanager.device.get_all(ctx, global_network_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.networkmanager.device.get_all global_network_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="networkmanager",
        operation="get_devices",
        op_kwargs={
            "GlobalNetworkId": global_network_id,
            "DeviceIds": device_ids,
            "SiteId": site_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    global_network_id: str,
    device_id: str,
    aws_location: Dict = None,
    description: str = None,
    type_: str = None,
    vendor: str = None,
    model: str = None,
    serial_number: str = None,
    location: Dict = None,
    site_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the details for an existing device. To remove information for any of the parameters, specify an empty string.

    Args:
        global_network_id(str): The ID of the global network.
        device_id(str): The ID of the device.
        aws_location(Dict, optional): The AWS location of the device. Defaults to None.
        description(str, optional): A description of the device. Length Constraints: Maximum length of 256 characters. Defaults to None.
        type_(str, optional): The type of the device. Defaults to None.
        vendor(str, optional): The vendor of the device. Length Constraints: Maximum length of 128 characters. Defaults to None.
        model(str, optional): The model of the device. Length Constraints: Maximum length of 128 characters. Defaults to None.
        serial_number(str, optional): The serial number of the device. Length Constraints: Maximum length of 128 characters. Defaults to None.
        location(Dict, optional): Describes a location. Defaults to None.
        site_id(str, optional): The ID of the site. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.networkmanager.device.update(
                ctx, global_network_id=value, device_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.networkmanager.device.update global_network_id=value, device_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="networkmanager",
        operation="update_device",
        op_kwargs={
            "GlobalNetworkId": global_network_id,
            "DeviceId": device_id,
            "AWSLocation": aws_location,
            "Description": description,
            "Type": type_,
            "Vendor": vendor,
            "Model": model,
            "SerialNumber": serial_number,
            "Location": location,
            "SiteId": site_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    definition: Dict,
    target: str,
    tags: List = None,
    greengrass_group_name: str = None,
    s3_bucket_name: str = None,
    metrics_configuration: Dict = None,
    flow_actions_role_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a system instance.  This action validates the system instance, prepares the deployment-related resources. For Greengrass deployments, it updates the Greengrass group that is specified by the greengrassGroupName parameter. It also adds a file to the S3 bucket specified by the s3BucketName parameter. You need to call DeploySystemInstance after running this action. For Greengrass deployments, since this action modifies and adds resources to a Greengrass group and an S3 bucket on the caller's behalf, the calling identity must have write permissions to both the specified Greengrass group and S3 bucket. Otherwise, the call will fail with an authorization error. For cloud deployments, this action requires a flowActionsRoleArn value. This is an IAM role that has permissions to access AWS services, such as AWS Lambda and AWS IoT, that the flow uses when it executes. If the definition document doesn't specify a version of the user's namespace, the latest version will be used by default.

    Args:
        tags(List, optional): Metadata, consisting of key-value pairs, that can be used to categorize your system instances. Defaults to None.
        definition(Dict): A document that defines an entity. .
        target(str): The target type of the deployment. Valid values are GREENGRASS and CLOUD.
        greengrass_group_name(str, optional): The name of the Greengrass group where the system instance will be deployed. This value is required if the value of the target parameter is GREENGRASS. Defaults to None.
        s3_bucket_name(str, optional): The name of the Amazon Simple Storage Service bucket that will be used to store and deploy the system instance's resource file. This value is required if the value of the target parameter is GREENGRASS. Defaults to None.
        metrics_configuration(Dict, optional): An object that specifies whether cloud metrics are collected in a deployment and, if so, what role is used to collect metrics. Defaults to None.
        flow_actions_role_arn(str, optional): The ARN of the IAM role that AWS IoT Things Graph will assume when it executes the flow. This role must have read and write access to AWS Lambda and AWS IoT and any other AWS services that the flow uses when it executes. This value is required if the value of the target parameter is CLOUD. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotthingsgraph.system.instance.create(
                ctx, definition=value, target=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotthingsgraph.system.instance.create definition=value, target=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotthingsgraph",
        operation="create_system_instance",
        op_kwargs={
            "tags": tags,
            "definition": definition,
            "target": target,
            "greengrassGroupName": greengrass_group_name,
            "s3BucketName": s3_bucket_name,
            "metricsConfiguration": metrics_configuration,
            "flowActionsRoleArn": flow_actions_role_arn,
        },
    )


async def delete(hub, ctx, id_: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a system instance. Only system instances that have never been deployed, or that have been undeployed can be deleted. Users can create a new system instance that has the same ID as a deleted system instance.

    Args:
        id_(str, optional): The ID of the system instance to be deleted. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotthingsgraph.system.instance.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotthingsgraph.system.instance.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotthingsgraph",
        operation="delete_system_instance",
        op_kwargs={"id": id_},
    )


async def deploy(hub, ctx, id_: str = None) -> Dict:
    r"""
    **Autogenerated function**

     Greengrass and Cloud Deployments  Deploys the system instance to the target specified in CreateSystemInstance.   Greengrass Deployments  If the system or any workflows and entities have been updated before this action is called, then the deployment will create a new Amazon Simple Storage Service resource file and then deploy it. Since this action creates a Greengrass deployment on the caller's behalf, the calling identity must have write permissions to the specified Greengrass group. Otherwise, the call will fail with an authorization error. For information about the artifacts that get added to your Greengrass core device when you use this API, see AWS IoT Things Graph and AWS IoT Greengrass.

    Args:
        id_(str, optional): The ID of the system instance. This value is returned by the CreateSystemInstance action. The ID should be in the following format.  urn:tdm:REGION/ACCOUNT ID/default:deployment:DEPLOYMENTNAME . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotthingsgraph.system.instance.deploy(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotthingsgraph.system.instance.deploy
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotthingsgraph",
        operation="deploy_system_instance",
        op_kwargs={"id": id_},
    )


async def get(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets a system instance.

    Args:
        id_(str): The ID of the system deployment instance. This value is returned by CreateSystemInstance. The ID should be in the following format.  urn:tdm:REGION/ACCOUNT ID/default:deployment:DEPLOYMENTNAME .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotthingsgraph.system.instance.get(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotthingsgraph.system.instance.get id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotthingsgraph",
        operation="get_system_instance",
        op_kwargs={"id": id_},
    )


async def search(
    hub, ctx, filters: List = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Searches for system instances in the user's account.

    Args:
        filters(List, optional): Optional filter to apply to the search. Valid filters are SYSTEM_TEMPLATE_ID, STATUS, and GREENGRASS_GROUP_NAME. Multiple filters function as OR criteria in the query. Multiple values passed inside the filter function as AND criteria. Defaults to None.
        next_token(str, optional): The string that specifies the next page of results. Use this when you're paginating results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotthingsgraph.system.instance.search(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotthingsgraph.system.instance.search
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotthingsgraph",
        operation="search_system_instances",
        op_kwargs={
            "filters": filters,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def undeploy(hub, ctx, id_: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Removes a system instance from its target (Cloud or Greengrass).

    Args:
        id_(str, optional): The ID of the system instance to remove from its target. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotthingsgraph.system.instance.undeploy(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotthingsgraph.system.instance.undeploy
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotthingsgraph",
        operation="undeploy_system_instance",
        op_kwargs={"id": id_},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, pull_request_id: str, approval_rule_name: str, approval_rule_content: str
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an approval rule for a pull request.

    Args:
        pull_request_id(str): The system-generated ID of the pull request for which you want to create the approval rule.
        approval_rule_name(str): The name for the approval rule.
        approval_rule_content(str): The content of the approval rule, including the number of approvals needed and the structure of an approval pool defined for approvals, if any. For more information about approval pools, see the AWS CodeCommit User Guide.  When you create the content of the approval rule, you can specify approvers in an approval pool in one of two ways:    CodeCommitApprovers: This option only requires an AWS account and a resource. It can be used for both IAM users and federated access users whose name matches the provided resource name. This is a very powerful option that offers a great deal of flexibility. For example, if you specify the AWS account 123456789012 and Mary_Major, all of the following would be counted as approvals coming from that user:   An IAM user in the account (arn:aws:iam::123456789012:user/Mary_Major)   A federated user identified in IAM as Mary_Major (arn:aws:sts::123456789012:federated-user/Mary_Major)   This option does not recognize an active session of someone assuming the role of CodeCommitReview with a role session name of Mary_Major (arn:aws:sts::123456789012:assumed-role/CodeCommitReview/Mary_Major) unless you include a wildcard (*Mary_Major).    Fully qualified ARN: This option allows you to specify the fully qualified Amazon Resource Name (ARN) of the IAM user or role.    For more information about IAM ARNs, wildcards, and formats, see IAM Identifiers in the IAM User Guide. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.pull_request.approval.rule.init.create(
                ctx, pull_request_id=value, approval_rule_name=value, approval_rule_content=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.pull_request.approval.rule.init.create pull_request_id=value, approval_rule_name=value, approval_rule_content=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="create_pull_request_approval_rule",
        op_kwargs={
            "pullRequestId": pull_request_id,
            "approvalRuleName": approval_rule_name,
            "approvalRuleContent": approval_rule_content,
        },
    )


async def delete(hub, ctx, pull_request_id: str, approval_rule_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an approval rule from a specified pull request. Approval rules can be deleted from a pull request only if the pull request is open, and if the approval rule was created specifically for a pull request and not generated from an approval rule template associated with the repository where the pull request was created. You cannot delete an approval rule from a merged or closed pull request.

    Args:
        pull_request_id(str): The system-generated ID of the pull request that contains the approval rule you want to delete.
        approval_rule_name(str): The name of the approval rule you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.pull_request.approval.rule.init.delete(
                ctx, pull_request_id=value, approval_rule_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.pull_request.approval.rule.init.delete pull_request_id=value, approval_rule_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="delete_pull_request_approval_rule",
        op_kwargs={
            "pullRequestId": pull_request_id,
            "approvalRuleName": approval_rule_name,
        },
    )


async def evaluate(hub, ctx, pull_request_id: str, revision_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Evaluates whether a pull request has met all the conditions specified in its associated approval rules.

    Args:
        pull_request_id(str): The system-generated ID of the pull request you want to evaluate.
        revision_id(str): The system-generated ID for the pull request revision. To retrieve the most recent revision ID for a pull request, use GetPullRequest.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.pull_request.approval.rule.init.evaluate(
                ctx, pull_request_id=value, revision_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.pull_request.approval.rule.init.evaluate pull_request_id=value, revision_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="evaluate_pull_request_approval_rules",
        op_kwargs={"pullRequestId": pull_request_id, "revisionId": revision_id},
    )


async def override(
    hub, ctx, pull_request_id: str, revision_id: str, override_status: str
) -> None:
    r"""
    **Autogenerated function**

    Sets aside (overrides) all approval rule requirements for a specified pull request.

    Args:
        pull_request_id(str): The system-generated ID of the pull request for which you want to override all approval rule requirements. To get this information, use GetPullRequest.
        revision_id(str): The system-generated ID of the most recent revision of the pull request. You cannot override approval rules for anything but the most recent revision of a pull request. To get the revision ID, use GetPullRequest.
        override_status(str): Whether you want to set aside approval rule requirements for the pull request (OVERRIDE) or revoke a previous override and apply approval rule requirements (REVOKE). REVOKE status is not stored.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.pull_request.approval.rule.init.override(
                ctx, pull_request_id=value, revision_id=value, override_status=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.pull_request.approval.rule.init.override pull_request_id=value, revision_id=value, override_status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="override_pull_request_approval_rules",
        op_kwargs={
            "pullRequestId": pull_request_id,
            "revisionId": revision_id,
            "overrideStatus": override_status,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(hub, ctx, client_arn: str, client_version: str, hapg_list: List) -> Dict:
    r"""
    **Autogenerated function**

    This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.  For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference. Gets the configuration files necessary to connect to all high availability partition groups the client is associated with.

    Args:
        client_arn(str): The ARN of the client.
        client_version(str): The client version.
        hapg_list(List): A list of ARNs that identify the high-availability partition groups that are associated with the client.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsm.config.get(
                ctx, client_arn=value, client_version=value, hapg_list=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsm.config.get client_arn=value, client_version=value, hapg_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudhsm",
        operation="get_config",
        op_kwargs={
            "ClientArn": client_arn,
            "ClientVersion": client_version,
            "HapgList": hapg_list,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def authorize(
    hub,
    ctx,
    cidr_ip: str = None,
    from_port: int = None,
    group_id: str = None,
    group_name: str = None,
    ip_permissions: List = None,
    ip_protocol: str = None,
    source_security_group_name: str = None,
    source_security_group_owner_id: str = None,
    to_port: int = None,
    dry_run: bool = None,
    tag_specifications: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds the specified inbound (ingress) rules to a security group. An inbound rule permits instances to receive traffic from the specified IPv4 or IPv6 CIDR address range, or from the instances that are associated with the specified destination security groups. You specify a protocol for each rule (for example, TCP). For TCP and UDP, you must also specify the destination port or port range. For ICMP/ICMPv6, you must also specify the ICMP/ICMPv6 type and code. You can use -1 to mean all types or all codes. Rule changes are propagated to instances within the security group as quickly as possible. However, a small delay might occur. For more information about VPC security group quotas, see Amazon VPC quotas.

    Args:
        cidr_ip(str, optional): The IPv4 address range, in CIDR format. You can't specify this parameter when specifying a source security group. To specify an IPv6 address range, use a set of IP permissions. Alternatively, use a set of IP permissions to specify multiple rules and a description for the rule. Defaults to None.
        from_port(int, optional): The start of port range for the TCP and UDP protocols, or an ICMP type number. For the ICMP type number, use -1 to specify all types. If you specify all ICMP types, you must specify all codes. Alternatively, use a set of IP permissions to specify multiple rules and a description for the rule. Defaults to None.
        group_id(str, optional): The ID of the security group. You must specify either the security group ID or the security group name in the request. For security groups in a nondefault VPC, you must specify the security group ID. Defaults to None.
        group_name(str, optional): [EC2-Classic, default VPC] The name of the security group. You must specify either the security group ID or the security group name in the request. Defaults to None.
        ip_permissions(List, optional): The sets of IP permissions. Defaults to None.
        ip_protocol(str, optional): The IP protocol name (tcp, udp, icmp) or number (see Protocol Numbers). To specify icmpv6, use a set of IP permissions. [VPC only] Use -1 to specify all protocols. If you specify -1 or a protocol other than tcp, udp, or icmp, traffic on all ports is allowed, regardless of any ports you specify. Alternatively, use a set of IP permissions to specify multiple rules and a description for the rule. Defaults to None.
        source_security_group_name(str, optional): [EC2-Classic, default VPC] The name of the source security group. You can't specify this parameter in combination with the following parameters: the CIDR IP address range, the start of the port range, the IP protocol, and the end of the port range. Creates rules that grant full ICMP, UDP, and TCP access. To create a rule with a specific IP protocol and port range, use a set of IP permissions instead. For EC2-VPC, the source security group must be in the same VPC. Defaults to None.
        source_security_group_owner_id(str, optional): [nondefault VPC] The Amazon Web Services account ID for the source security group, if the source security group is in a different account. You can't specify this parameter in combination with the following parameters: the CIDR IP address range, the IP protocol, the start of the port range, and the end of the port range. Creates rules that grant full ICMP, UDP, and TCP access. To create a rule with a specific IP protocol and port range, use a set of IP permissions instead. Defaults to None.
        to_port(int, optional): The end of port range for the TCP and UDP protocols, or an ICMP code number. For the ICMP code number, use -1 to specify all codes. If you specify all ICMP types, you must specify all codes. Alternatively, use a set of IP permissions to specify multiple rules and a description for the rule. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        tag_specifications(List, optional): [VPC Only] The tags applied to the security group rule. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.security_group.ingress.authorize(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.security_group.ingress.authorize
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="authorize_security_group_ingress",
        op_kwargs={
            "CidrIp": cidr_ip,
            "FromPort": from_port,
            "GroupId": group_id,
            "GroupName": group_name,
            "IpPermissions": ip_permissions,
            "IpProtocol": ip_protocol,
            "SourceSecurityGroupName": source_security_group_name,
            "SourceSecurityGroupOwnerId": source_security_group_owner_id,
            "ToPort": to_port,
            "DryRun": dry_run,
            "TagSpecifications": tag_specifications,
        },
    )


async def revoke(
    hub,
    ctx,
    cidr_ip: str = None,
    from_port: int = None,
    group_id: str = None,
    group_name: str = None,
    ip_permissions: List = None,
    ip_protocol: str = None,
    source_security_group_name: str = None,
    source_security_group_owner_id: str = None,
    to_port: int = None,
    dry_run: bool = None,
    security_group_rule_ids: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Removes the specified inbound (ingress) rules from a security group. You can specify rules using either rule IDs or security group rule properties. If you use rule properties, the values that you specify (for example, ports) must match the existing rule's values exactly. Each rule has a protocol, from and to ports, and source (CIDR range, security group, or prefix list). For the TCP and UDP protocols, you must also specify the destination port or range of ports. For the ICMP protocol, you must also specify the ICMP type and code. If the security group rule has a description, you do not need to specify the description to revoke the rule. [EC2-Classic, default VPC] If the values you specify do not match the existing rule's values, no error is returned, and the output describes the security group rules that were not revoked. Amazon Web Services recommends that you describe the security group to verify that the rules were removed. Rule changes are propagated to instances within the security group as quickly as possible. However, a small delay might occur.

    Args:
        cidr_ip(str, optional): The CIDR IP address range. You can't specify this parameter when specifying a source security group. Defaults to None.
        from_port(int, optional): The start of port range for the TCP and UDP protocols, or an ICMP type number. For the ICMP type number, use -1 to specify all ICMP types. Defaults to None.
        group_id(str, optional): The ID of the security group. You must specify either the security group ID or the security group name in the request. For security groups in a nondefault VPC, you must specify the security group ID. Defaults to None.
        group_name(str, optional): [EC2-Classic, default VPC] The name of the security group. You must specify either the security group ID or the security group name in the request. Defaults to None.
        ip_permissions(List, optional): The sets of IP permissions. You can't specify a source security group and a CIDR IP address range in the same set of permissions. Defaults to None.
        ip_protocol(str, optional): The IP protocol name (tcp, udp, icmp) or number (see Protocol Numbers). Use -1 to specify all. Defaults to None.
        source_security_group_name(str, optional): [EC2-Classic, default VPC] The name of the source security group. You can't specify this parameter in combination with the following parameters: the CIDR IP address range, the start of the port range, the IP protocol, and the end of the port range. For EC2-VPC, the source security group must be in the same VPC. To revoke a specific rule for an IP protocol and port range, use a set of IP permissions instead. Defaults to None.
        source_security_group_owner_id(str, optional): [EC2-Classic] The Amazon Web Services account ID of the source security group, if the source security group is in a different account. You can't specify this parameter in combination with the following parameters: the CIDR IP address range, the IP protocol, the start of the port range, and the end of the port range. To revoke a specific rule for an IP protocol and port range, use a set of IP permissions instead. Defaults to None.
        to_port(int, optional): The end of port range for the TCP and UDP protocols, or an ICMP code number. For the ICMP code number, use -1 to specify all ICMP codes for the ICMP type. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        security_group_rule_ids(List, optional): The IDs of the security group rules. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.security_group.ingress.revoke(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.security_group.ingress.revoke
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="revoke_security_group_ingress",
        op_kwargs={
            "CidrIp": cidr_ip,
            "FromPort": from_port,
            "GroupId": group_id,
            "GroupName": group_name,
            "IpPermissions": ip_permissions,
            "IpProtocol": ip_protocol,
            "SourceSecurityGroupName": source_security_group_name,
            "SourceSecurityGroupOwnerId": source_security_group_owner_id,
            "ToPort": to_port,
            "DryRun": dry_run,
            "SecurityGroupRuleIds": security_group_rule_ids,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(
    hub, ctx, lifecycle_hook_name: str, auto_scaling_group_name: str
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified lifecycle hook. If there are any outstanding lifecycle actions, they are completed first (ABANDON for launching instances, CONTINUE for terminating instances).

    Args:
        lifecycle_hook_name(str): The name of the lifecycle hook.
        auto_scaling_group_name(str): The name of the Auto Scaling group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.lifecycle.hook.init.delete(
                ctx, lifecycle_hook_name=value, auto_scaling_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.lifecycle.hook.init.delete lifecycle_hook_name=value, auto_scaling_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="delete_lifecycle_hook",
        op_kwargs={
            "LifecycleHookName": lifecycle_hook_name,
            "AutoScalingGroupName": auto_scaling_group_name,
        },
    )


async def describe_all(
    hub, ctx, auto_scaling_group_name: str, lifecycle_hook_names: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the lifecycle hooks for the specified Auto Scaling group.

    Args:
        auto_scaling_group_name(str): The name of the Auto Scaling group.
        lifecycle_hook_names(List, optional): The names of one or more lifecycle hooks. If you omit this parameter, all lifecycle hooks are described. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.lifecycle.hook.init.describe_all(
                ctx, auto_scaling_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.lifecycle.hook.init.describe_all auto_scaling_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="describe_lifecycle_hooks",
        op_kwargs={
            "AutoScalingGroupName": auto_scaling_group_name,
            "LifecycleHookNames": lifecycle_hook_names,
        },
    )


async def put(
    hub,
    ctx,
    lifecycle_hook_name: str,
    auto_scaling_group_name: str,
    lifecycle_transition: str = None,
    role_arn: str = None,
    notification_target_arn: str = None,
    notification_metadata: str = None,
    heartbeat_timeout: int = None,
    default_result: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates or updates a lifecycle hook for the specified Auto Scaling group. A lifecycle hook tells Amazon EC2 Auto Scaling to perform an action on an instance when the instance launches (before it is put into service) or as the instance terminates (before it is fully terminated). This step is a part of the procedure for adding a lifecycle hook to an Auto Scaling group:   (Optional) Create a Lambda function and a rule that allows CloudWatch Events to invoke your Lambda function when Amazon EC2 Auto Scaling launches or terminates instances.   (Optional) Create a notification target and an IAM role. The target can be either an Amazon SQS queue or an Amazon SNS topic. The role allows Amazon EC2 Auto Scaling to publish lifecycle notifications to the target.    Create the lifecycle hook. Specify whether the hook is used when the instances launch or terminate.    If you need more time, record the lifecycle action heartbeat to keep the instance in a pending state using the RecordLifecycleActionHeartbeat API call.   If you finish before the timeout period ends, complete the lifecycle action using the CompleteLifecycleAction API call.   For more information, see Amazon EC2 Auto Scaling lifecycle hooks in the Amazon EC2 Auto Scaling User Guide. If you exceed your maximum limit of lifecycle hooks, which by default is 50 per Auto Scaling group, the call fails. You can view the lifecycle hooks for an Auto Scaling group using the DescribeLifecycleHooks API call. If you are no longer using a lifecycle hook, you can delete it by calling the DeleteLifecycleHook API.

    Args:
        lifecycle_hook_name(str): The name of the lifecycle hook.
        auto_scaling_group_name(str): The name of the Auto Scaling group.
        lifecycle_transition(str, optional): The instance state to which you want to attach the lifecycle hook. The valid values are:   autoscaling:EC2_INSTANCE_LAUNCHING   autoscaling:EC2_INSTANCE_TERMINATING   Required for new lifecycle hooks, but optional when updating existing hooks. Defaults to None.
        role_arn(str, optional): The ARN of the IAM role that allows the Auto Scaling group to publish to the specified notification target, for example, an Amazon SNS topic or an Amazon SQS queue. Required for new lifecycle hooks, but optional when updating existing hooks. Defaults to None.
        notification_target_arn(str, optional): The ARN of the notification target that Amazon EC2 Auto Scaling uses to notify you when an instance is in the transition state for the lifecycle hook. This target can be either an SQS queue or an SNS topic. If you specify an empty string, this overrides the current ARN. This operation uses the JSON format when sending notifications to an Amazon SQS queue, and an email key-value pair format when sending notifications to an Amazon SNS topic. When you specify a notification target, Amazon EC2 Auto Scaling sends it a test message. Test messages contain the following additional key-value pair: "Event": "autoscaling:TEST_NOTIFICATION". Defaults to None.
        notification_metadata(str, optional): Additional information that you want to include any time Amazon EC2 Auto Scaling sends a message to the notification target. Defaults to None.
        heartbeat_timeout(int, optional): The maximum time, in seconds, that can elapse before the lifecycle hook times out. The range is from 30 to 7200 seconds. The default value is 3600 seconds (1 hour). If the lifecycle hook times out, Amazon EC2 Auto Scaling performs the action that you specified in the DefaultResult parameter. You can prevent the lifecycle hook from timing out by calling the RecordLifecycleActionHeartbeat API. Defaults to None.
        default_result(str, optional): Defines the action the Auto Scaling group should take when the lifecycle hook timeout elapses or if an unexpected failure occurs. This parameter can be either CONTINUE or ABANDON. The default value is ABANDON. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.lifecycle.hook.init.put(
                ctx, lifecycle_hook_name=value, auto_scaling_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.lifecycle.hook.init.put lifecycle_hook_name=value, auto_scaling_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="put_lifecycle_hook",
        op_kwargs={
            "LifecycleHookName": lifecycle_hook_name,
            "AutoScalingGroupName": auto_scaling_group_name,
            "LifecycleTransition": lifecycle_transition,
            "RoleARN": role_arn,
            "NotificationTargetARN": notification_target_arn,
            "NotificationMetadata": notification_metadata,
            "HeartbeatTimeout": heartbeat_timeout,
            "DefaultResult": default_result,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    domain_name: str,
    auth_mode: str,
    default_user_settings: Dict,
    subnet_ids: List,
    vpc_id: str,
    tags: List = None,
    app_network_access_type: str = None,
    home_efs_file_system_kms_key_id: str = None,
    kms_key_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Domain used by Amazon SageMaker Studio. A domain consists of an associated Amazon Elastic File System (EFS) volume, a list of authorized users, and a variety of security, application, policy, and Amazon Virtual Private Cloud (VPC) configurations. An Amazon Web Services account is limited to one domain per region. Users within a domain can share notebook files and other artifacts with each other.  EFS storage  When a domain is created, an EFS volume is created for use by all of the users within the domain. Each user receives a private home directory within the EFS volume for notebooks, Git repositories, and data files. SageMaker uses the Amazon Web Services Key Management Service (Amazon Web Services KMS) to encrypt the EFS volume attached to the domain with an Amazon Web Services managed customer master key (CMK) by default. For more control, you can specify a customer managed CMK. For more information, see Protect Data at Rest Using Encryption.  VPC configuration  All SageMaker Studio traffic between the domain and the EFS volume is through the specified VPC and subnets. For other Studio traffic, you can specify the AppNetworkAccessType parameter. AppNetworkAccessType corresponds to the network access type that you choose when you onboard to Studio. The following options are available:    PublicInternetOnly - Non-EFS traffic goes through a VPC managed by Amazon SageMaker, which allows internet access. This is the default value.    VpcOnly - All Studio traffic is through the specified VPC and subnets. Internet access is disabled by default. To allow internet access, you must specify a NAT gateway. When internet access is disabled, you won't be able to run a Studio notebook or to train or host models unless your VPC has an interface endpoint to the SageMaker API and runtime or a NAT gateway and your security groups allow outbound connections.    NFS traffic over TCP on port 2049 needs to be allowed in both inbound and outbound rules in order to launch a SageMaker Studio app successfully.  For more information, see Connect SageMaker Studio Notebooks to Resources in a VPC.

    Args:
        domain_name(str): A name for the domain.
        auth_mode(str): The mode of authentication that members use to access the domain.
        default_user_settings(Dict): The default settings to use to create a user profile when UserSettings isn't specified in the call to the CreateUserProfile API.  SecurityGroups is aggregated when specified in both calls. For all other settings in UserSettings, the values specified in CreateUserProfile take precedence over those specified in CreateDomain.
        subnet_ids(List): The VPC subnets that Studio uses for communication.
        vpc_id(str): The ID of the Amazon Virtual Private Cloud (VPC) that Studio uses for communication.
        tags(List, optional): Tags to associated with the Domain. Each tag consists of a key and an optional value. Tag keys must be unique per resource. Tags are searchable using the Search API. Tags that you specify for the Domain are also added to all Apps that the Domain launches. Defaults to None.
        app_network_access_type(str, optional): Specifies the VPC used for non-EFS traffic. The default value is PublicInternetOnly.    PublicInternetOnly - Non-EFS traffic is through a VPC managed by Amazon SageMaker, which allows direct internet access    VpcOnly - All Studio traffic is through the specified VPC and subnets  . Defaults to None.
        home_efs_file_system_kms_key_id(str, optional): This member is deprecated and replaced with KmsKeyId. Defaults to None.
        kms_key_id(str, optional): SageMaker uses Amazon Web Services KMS to encrypt the EFS volume attached to the domain with an Amazon Web Services managed customer master key (CMK) by default. For more control, specify a customer managed CMK. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.domain.create(
                ctx,
                domain_name=value,
                auth_mode=value,
                default_user_settings=value,
                subnet_ids=value,
                vpc_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.domain.create domain_name=value, auth_mode=value, default_user_settings=value, subnet_ids=value, vpc_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_domain",
        op_kwargs={
            "DomainName": domain_name,
            "AuthMode": auth_mode,
            "DefaultUserSettings": default_user_settings,
            "SubnetIds": subnet_ids,
            "VpcId": vpc_id,
            "Tags": tags,
            "AppNetworkAccessType": app_network_access_type,
            "HomeEfsFileSystemKmsKeyId": home_efs_file_system_kms_key_id,
            "KmsKeyId": kms_key_id,
        },
    )


async def delete(hub, ctx, domain_id: str, retention_policy: Dict = None) -> None:
    r"""
    **Autogenerated function**

    Used to delete a domain. If you onboarded with IAM mode, you will need to delete your domain to onboard again using SSO. Use with caution. All of the members of the domain will lose access to their EFS volume, including data, notebooks, and other artifacts.

    Args:
        domain_id(str): The domain ID.
        retention_policy(Dict, optional): The retention policy for this domain, which specifies whether resources will be retained after the Domain is deleted. By default, all resources are retained (not automatically deleted). . Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.domain.delete(ctx, domain_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.domain.delete domain_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_domain",
        op_kwargs={"DomainId": domain_id, "RetentionPolicy": retention_policy},
    )


async def describe(hub, ctx, domain_id: str) -> Dict:
    r"""
    **Autogenerated function**

    The description of the domain.

    Args:
        domain_id(str): The domain ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.domain.describe(ctx, domain_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.domain.describe domain_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_domain",
        op_kwargs={"DomainId": domain_id},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the domains.

    Args:
        next_token(str, optional): If the previous response was truncated, you will receive this token. Use it in your next request to receive the next set of results. Defaults to None.
        max_results(int, optional): Returns a list up to a specified limit. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.domain.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.domain.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_domains",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )


async def update(hub, ctx, domain_id: str, default_user_settings: Dict = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates the default settings for new user profiles in the domain.

    Args:
        domain_id(str): The ID of the domain to be updated.
        default_user_settings(Dict, optional): A collection of settings. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.domain.update(ctx, domain_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.domain.update domain_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="update_domain",
        op_kwargs={"DomainId": domain_id, "DefaultUserSettings": default_user_settings},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    api_id: str,
    integration_id: str,
    integration_response_key: str,
    content_handling_strategy: str = None,
    response_parameters: Dict = None,
    response_templates: Dict = None,
    template_selection_expression: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an IntegrationResponses.

    Args:
        api_id(str): The API identifier.
        content_handling_strategy(str, optional): Specifies how to handle response payload content type conversions. Supported values are CONVERT_TO_BINARY and CONVERT_TO_TEXT, with the following behaviors: CONVERT_TO_BINARY: Converts a response payload from a Base64-encoded string to the corresponding binary blob. CONVERT_TO_TEXT: Converts a response payload from a binary blob to a Base64-encoded string. If this property is not defined, the response payload will be passed through from the integration response to the route response or method response without modification. Defaults to None.
        integration_id(str): The integration ID.
        integration_response_key(str): The integration response key.
        response_parameters(Dict, optional): A key-value map specifying response parameters that are passed to the method response from the backend. The key is a method response header parameter name and the mapped value is an integration response header value, a static value enclosed within a pair of single quotes, or a JSON expression from the integration response body. The mapping key must match the pattern of method.response.header.{name}, where {name} is a valid and unique header name. The mapped non-static value must match the pattern of integration.response.header.{name} or integration.response.body.{JSON-expression}, where {name} is a valid and unique response header name and {JSON-expression} is a valid JSON expression without the $ prefix. Defaults to None.
        response_templates(Dict, optional): The collection of response templates for the integration response as a string-to-string map of key-value pairs. Response templates are represented as a key/value map, with a content-type as the key and a template as the value. Defaults to None.
        template_selection_expression(str, optional): The template selection expression for the integration response. Supported only for WebSocket APIs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.integration.response.create(
                ctx, api_id=value, integration_id=value, integration_response_key=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.integration.response.create api_id=value, integration_id=value, integration_response_key=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="create_integration_response",
        op_kwargs={
            "ApiId": api_id,
            "ContentHandlingStrategy": content_handling_strategy,
            "IntegrationId": integration_id,
            "IntegrationResponseKey": integration_response_key,
            "ResponseParameters": response_parameters,
            "ResponseTemplates": response_templates,
            "TemplateSelectionExpression": template_selection_expression,
        },
    )


async def delete(
    hub, ctx, api_id: str, integration_id: str, integration_response_id: str
) -> None:
    r"""
    **Autogenerated function**

    Deletes an IntegrationResponses.

    Args:
        api_id(str): The API identifier.
        integration_id(str): The integration ID.
        integration_response_id(str): The integration response ID.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.integration.response.delete(
                ctx, api_id=value, integration_id=value, integration_response_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.integration.response.delete api_id=value, integration_id=value, integration_response_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="delete_integration_response",
        op_kwargs={
            "ApiId": api_id,
            "IntegrationId": integration_id,
            "IntegrationResponseId": integration_response_id,
        },
    )


async def get(
    hub, ctx, api_id: str, integration_id: str, integration_response_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Gets an IntegrationResponses.

    Args:
        api_id(str): The API identifier.
        integration_id(str): The integration ID.
        integration_response_id(str): The integration response ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.integration.response.get(
                ctx, api_id=value, integration_id=value, integration_response_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.integration.response.get api_id=value, integration_id=value, integration_response_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="get_integration_response",
        op_kwargs={
            "ApiId": api_id,
            "IntegrationId": integration_id,
            "IntegrationResponseId": integration_response_id,
        },
    )


async def get_all(
    hub,
    ctx,
    api_id: str,
    integration_id: str,
    max_results: str = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the IntegrationResponses for an Integration.

    Args:
        api_id(str): The API identifier.
        integration_id(str): The integration ID.
        max_results(str, optional): The maximum number of elements to be returned for this resource. Defaults to None.
        next_token(str, optional): The next page of elements from this collection. Not valid for the last element of the collection. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.integration.response.get_all(
                ctx, api_id=value, integration_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.integration.response.get_all api_id=value, integration_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="get_integration_responses",
        op_kwargs={
            "ApiId": api_id,
            "IntegrationId": integration_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    api_id: str,
    integration_id: str,
    integration_response_id: str,
    content_handling_strategy: str = None,
    integration_response_key: str = None,
    response_parameters: Dict = None,
    response_templates: Dict = None,
    template_selection_expression: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an IntegrationResponses.

    Args:
        api_id(str): The API identifier.
        content_handling_strategy(str, optional): Supported only for WebSocket APIs. Specifies how to handle response payload content type conversions. Supported values are CONVERT_TO_BINARY and CONVERT_TO_TEXT, with the following behaviors: CONVERT_TO_BINARY: Converts a response payload from a Base64-encoded string to the corresponding binary blob. CONVERT_TO_TEXT: Converts a response payload from a binary blob to a Base64-encoded string. If this property is not defined, the response payload will be passed through from the integration response to the route response or method response without modification. Defaults to None.
        integration_id(str): The integration ID.
        integration_response_id(str): The integration response ID.
        integration_response_key(str, optional): The integration response key. Defaults to None.
        response_parameters(Dict, optional): A key-value map specifying response parameters that are passed to the method response from the backend. The key is a method response header parameter name and the mapped value is an integration response header value, a static value enclosed within a pair of single quotes, or a JSON expression from the integration response body. The mapping key must match the pattern of method.response.header.{name}
               , where name is a valid and unique header name. The mapped non-static value must match the pattern of integration.response.header.{name}
                or integration.response.body.{JSON-expression}
               , where
                  {name}
                is a valid and unique response header name and
                  {JSON-expression}
                is a valid JSON expression without the $ prefix. Defaults to None.
        response_templates(Dict, optional): The collection of response templates for the integration response as a string-to-string map of key-value pairs. Response templates are represented as a key/value map, with a content-type as the key and a template as the value. Defaults to None.
        template_selection_expression(str, optional): The template selection expression for the integration response. Supported only for WebSocket APIs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.integration.response.update(
                ctx, api_id=value, integration_id=value, integration_response_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.integration.response.update api_id=value, integration_id=value, integration_response_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="update_integration_response",
        op_kwargs={
            "ApiId": api_id,
            "ContentHandlingStrategy": content_handling_strategy,
            "IntegrationId": integration_id,
            "IntegrationResponseId": integration_response_id,
            "IntegrationResponseKey": integration_response_key,
            "ResponseParameters": response_parameters,
            "ResponseTemplates": response_templates,
            "TemplateSelectionExpression": template_selection_expression,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    folder_id: str,
    authentication_token: str = None,
    limit: int = None,
    fields: str = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the path information (the hierarchy from the root folder) for the specified folder. By default, Amazon WorkDocs returns a maximum of 100 levels upwards from the requested folder and only includes the IDs of the parent folders in the path. You can limit the maximum number of levels. You can also request the parent folder names.

    Args:
        authentication_token(str, optional): Amazon WorkDocs authentication token. Not required when using AWS administrator credentials to access the API. Defaults to None.
        folder_id(str): The ID of the folder.
        limit(int, optional): The maximum number of levels in the hierarchy to return. Defaults to None.
        fields(str, optional): A comma-separated list of values. Specify "NAME" to include the names of the parent folders. Defaults to None.
        marker(str, optional): This value is not supported. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workdoc.folder.path.get(ctx, folder_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workdoc.folder.path.get folder_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workdocs",
        operation="get_folder_path",
        op_kwargs={
            "AuthenticationToken": authentication_token,
            "FolderId": folder_id,
            "Limit": limit,
            "Fields": fields,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub, ctx, policy_id: str, member_account: str, resource_id: str, resource_type: str
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves violations for a resource based on the specified Firewall Manager policy and Amazon Web Services account.

    Args:
        policy_id(str): The ID of the Firewall Manager policy that you want the details for. This currently only supports security group content audit policies.
        member_account(str): The Amazon Web Services account ID that you want the details for.
        resource_id(str): The ID of the resource that has violations.
        resource_type(str): The resource type. This is in the format shown in the Amazon Web Services Resource Types Reference. Supported resource types are: AWS::EC2::Instance, AWS::EC2::NetworkInterface, AWS::EC2::SecurityGroup, AWS::NetworkFirewall::FirewallPolicy, and AWS::EC2::Subnet. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fms.violation_detail.get_all(
                ctx, policy_id=value, member_account=value, resource_id=value, resource_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fms.violation_detail.get_all policy_id=value, member_account=value, resource_id=value, resource_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fms",
        operation="get_violation_details",
        op_kwargs={
            "PolicyId": policy_id,
            "MemberAccount": member_account,
            "ResourceId": resource_id,
            "ResourceType": resource_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub, ctx, filters: List = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Provides details about all active and terminated Automation executions.

    Args:
        filters(List, optional): Filters used to limit the scope of executions that are requested. Defaults to None.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.automation.execution.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.automation.execution.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="describe_automation_executions",
        op_kwargs={
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def get(hub, ctx, automation_execution_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Get detailed information about a particular Automation execution.

    Args:
        automation_execution_id(str): The unique identifier for an existing automation execution to examine. The execution ID is returned by StartAutomationExecution when the execution of an Automation runbook is initiated.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.automation.execution.get(ctx, automation_execution_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.automation.execution.get automation_execution_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="get_automation_execution",
        op_kwargs={"AutomationExecutionId": automation_execution_id},
    )


async def start(
    hub,
    ctx,
    document_name: str,
    document_version: str = None,
    parameters: Dict = None,
    client_token: str = None,
    mode: str = None,
    target_parameter_name: str = None,
    targets: List = None,
    target_maps: List = None,
    max_concurrency: str = None,
    max_errors: str = None,
    target_locations: List = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Initiates execution of an Automation runbook.

    Args:
        document_name(str): The name of the SSM document to run. This can be a public document or a custom document. To run a shared document belonging to another account, specify the document ARN. For more information about how to use shared documents, see Using shared SSM documents in the Amazon Web Services Systems Manager User Guide.
        document_version(str, optional): The version of the Automation runbook to use for this execution. Defaults to None.
        parameters(Dict, optional): A key-value map of execution parameters, which match the declared parameters in the Automation runbook. Defaults to None.
        client_token(str, optional): User-provided idempotency token. The token must be unique, is case insensitive, enforces the UUID format, and can't be reused. Defaults to None.
        mode(str, optional): The execution mode of the automation. Valid modes include the following: Auto and Interactive. The default mode is Auto. Defaults to None.
        target_parameter_name(str, optional): The name of the parameter used as the target resource for the rate-controlled execution. Required if you specify targets. Defaults to None.
        targets(List, optional): A key-value mapping to target resources. Required if you specify TargetParameterName. Defaults to None.
        target_maps(List, optional): A key-value mapping of document parameters to target resources. Both Targets and TargetMaps can't be specified together. Defaults to None.
        max_concurrency(str, optional): The maximum number of targets allowed to run this task in parallel. You can specify a number, such as 10, or a percentage, such as 10%. The default value is 10. Defaults to None.
        max_errors(str, optional): The number of errors that are allowed before the system stops running the automation on additional targets. You can specify either an absolute number of errors, for example 10, or a percentage of the target set, for example 10%. If you specify 3, for example, the system stops running the automation when the fourth error is received. If you specify 0, then the system stops running the automation on additional targets after the first error result is returned. If you run an automation on 50 resources and set max-errors to 10%, then the system stops running the automation on additional targets when the sixth error is received. Executions that are already running an automation when max-errors is reached are allowed to complete, but some of these executions may fail as well. If you need to ensure that there won't be more than max-errors failed executions, set max-concurrency to 1 so the executions proceed one at a time. Defaults to None.
        target_locations(List, optional): A location is a combination of Regions and/or accounts where you want to run the automation. Use this operation to start an automation in multiple Regions and multiple accounts. For more information, see Running Automation workflows in multiple Regions and accounts in the Amazon Web Services Systems Manager User Guide. . Defaults to None.
        tags(List, optional): Optional metadata that you assign to a resource. You can specify a maximum of five tags for an automation. Tags enable you to categorize a resource in different ways, such as by purpose, owner, or environment. For example, you might want to tag an automation to identify an environment or operating system. In this case, you could specify the following key-value pairs:    Key=environment,Value=test     Key=OS,Value=Windows     To add tags to an existing patch baseline, use the AddTagsToResource operation. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.automation.execution.start(ctx, document_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.automation.execution.start document_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="start_automation_execution",
        op_kwargs={
            "DocumentName": document_name,
            "DocumentVersion": document_version,
            "Parameters": parameters,
            "ClientToken": client_token,
            "Mode": mode,
            "TargetParameterName": target_parameter_name,
            "Targets": targets,
            "TargetMaps": target_maps,
            "MaxConcurrency": max_concurrency,
            "MaxErrors": max_errors,
            "TargetLocations": target_locations,
            "Tags": tags,
        },
    )


async def stop(hub, ctx, automation_execution_id: str, type_: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Stop an Automation that is currently running.

    Args:
        automation_execution_id(str): The execution ID of the Automation to stop.
        type_(str, optional): The stop request type. Valid types include the following: Cancel and Complete. The default type is Cancel. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.automation.execution.stop(
                ctx, automation_execution_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.automation.execution.stop automation_execution_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="stop_automation_execution",
        op_kwargs={"AutomationExecutionId": automation_execution_id, "Type": type_},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    export_to_s3_task: Dict,
    instance_id: str,
    target_environment: str,
    description: str = None,
    tag_specifications: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Exports a running or stopped instance to an Amazon S3 bucket. For information about the supported operating systems, image formats, and known limitations for the types of instances you can export, see Exporting an instance as a VM Using VM Import/Export in the VM Import/Export User Guide.

    Args:
        description(str, optional): A description for the conversion task or the resource being exported. The maximum length is 255 characters. Defaults to None.
        export_to_s3_task(Dict): The format and location for an export instance task.
        instance_id(str): The ID of the instance.
        target_environment(str): The target virtualization environment.
        tag_specifications(List, optional): The tags to apply to the export instance task during creation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.export_task.create(
                ctx, export_to_s3_task=value, instance_id=value, target_environment=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.export_task.create export_to_s3_task=value, instance_id=value, target_environment=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_instance_export_task",
        op_kwargs={
            "Description": description,
            "ExportToS3Task": export_to_s3_task,
            "InstanceId": instance_id,
            "TargetEnvironment": target_environment,
            "TagSpecifications": tag_specifications,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def remove(hub, ctx, tags: List, instance_names: List) -> None:
    r"""
    **Autogenerated function**

    Removes one or more tags from one or more on-premises instances.

    Args:
        tags(List): The tag key-value pairs to remove from the on-premises instances.
        instance_names(List): The names of the on-premises instances from which to remove tags.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.tags.from_on_premise_instance.remove(
                ctx, tags=value, instance_names=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.tags.from_on_premise_instance.remove tags=value, instance_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="remove_tags_from_on_premises_instances",
        op_kwargs={"tags": tags, "instanceNames": instance_names},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, insight_id: str, start_time: str, end_time: str, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a service graph structure filtered by the specified insight. The service graph is limited to only structural information. For a complete service graph, use this API with the GetServiceGraph API.

    Args:
        insight_id(str): The insight's unique identifier. Use the GetInsightSummaries action to retrieve an InsightId.
        start_time(str): The estimated start time of the insight, in Unix time seconds. The StartTime is inclusive of the value provided and can't be more than 30 days old.
        end_time(str): The estimated end time of the insight, in Unix time seconds. The EndTime is exclusive of the value provided. The time range between the start time and end time can't be more than six hours. .
        next_token(str, optional): Specify the pagination token returned by a previous request to retrieve the next page of results. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.xray.insight.impact_graph.get(
                ctx, insight_id=value, start_time=value, end_time=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.xray.insight.impact_graph.get insight_id=value, start_time=value, end_time=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="xray",
        operation="get_insight_impact_graph",
        op_kwargs={
            "InsightId": insight_id,
            "StartTime": start_time,
            "EndTime": end_time,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"import_": "import"}


async def delete(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a specified authorization key pair. This invalidates future viewer tokens generated using the key pair’s privateKey. For more information, see Setting Up Private Channels in the Amazon IVS User Guide.

    Args:
        arn(str): ARN of the key pair to be deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ivs.playback_key_pair.delete(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ivs.playback_key_pair.delete arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ivs",
        operation="delete_playback_key_pair",
        op_kwargs={"arn": arn},
    )


async def get(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets a specified playback authorization key pair and returns the arn and fingerprint. The privateKey held by the caller can be used to generate viewer authorization tokens, to grant viewers access to private channels. For more information, see Setting Up Private Channels in the Amazon IVS User Guide.

    Args:
        arn(str): ARN of the key pair to be returned.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ivs.playback_key_pair.get(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ivs.playback_key_pair.get arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ivs",
        operation="get_playback_key_pair",
        op_kwargs={"arn": arn},
    )


async def import_(
    hub, ctx, public_key_material: str, name: str = None, tags: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Imports the public portion of a new key pair and returns its arn and fingerprint. The privateKey can then be used to generate viewer authorization tokens, to grant viewers access to private channels. For more information, see Setting Up Private Channels in the Amazon IVS User Guide.

    Args:
        public_key_material(str): The public portion of a customer-generated key pair.
        name(str, optional): An arbitrary string (a nickname) assigned to a playback key pair that helps the customer identify that resource. The value does not need to be unique. Defaults to None.
        tags(Dict, optional): Any tags provided with the request are added to the playback key pair tags. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ivs.playback_key_pair.import(ctx, public_key_material=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ivs.playback_key_pair.import public_key_material=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ivs",
        operation="import_playback_key_pair",
        op_kwargs={
            "publicKeyMaterial": public_key_material,
            "name": name,
            "tags": tags,
        },
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets summary information about playback key pairs. For more information, see Setting Up Private Channels in the Amazon IVS User Guide.

    Args:
        next_token(str, optional): Maximum number of key pairs to return. Defaults to None.
        max_results(int, optional): The first key pair to retrieve. This is used for pagination; see the nextToken response field. Default: 50. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ivs.playback_key_pair.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ivs.playback_key_pair.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ivs",
        operation="list_playback_key_pairs",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def attach(
    hub, ctx, directory_arn: str, policy_reference: Dict, object_reference: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Attaches a policy object to a regular object. An object can have a limited number of attached policies.

    Args:
        directory_arn(str): The Amazon Resource Name (ARN) that is associated with the Directory where both objects reside. For more information, see arns.
        policy_reference(Dict): The reference that is associated with the policy object.
        object_reference(Dict): The reference that identifies the object to which the policy will be attached.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.policy.init.attach(
                ctx, directory_arn=value, policy_reference=value, object_reference=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.policy.init.attach directory_arn=value, policy_reference=value, object_reference=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="attach_policy",
        op_kwargs={
            "DirectoryArn": directory_arn,
            "PolicyReference": policy_reference,
            "ObjectReference": object_reference,
        },
    )


async def detach(
    hub, ctx, directory_arn: str, policy_reference: Dict, object_reference: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Detaches a policy from an object.

    Args:
        directory_arn(str): The Amazon Resource Name (ARN) that is associated with the Directory where both objects reside. For more information, see arns.
        policy_reference(Dict): Reference that identifies the policy object.
        object_reference(Dict): Reference that identifies the object whose policy object will be detached.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.policy.init.detach(
                ctx, directory_arn=value, policy_reference=value, object_reference=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.policy.init.detach directory_arn=value, policy_reference=value, object_reference=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="detach_policy",
        op_kwargs={
            "DirectoryArn": directory_arn,
            "PolicyReference": policy_reference,
            "ObjectReference": object_reference,
        },
    )


async def lookup(
    hub,
    ctx,
    directory_arn: str,
    object_reference: Dict,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all policies from the root of the Directory to the object specified. If there are no policies present, an empty list is returned. If policies are present, and if some objects don't have the policies attached, it returns the ObjectIdentifier for such objects. If policies are present, it returns ObjectIdentifier, policyId, and policyType. Paths that don't lead to the root from the target object are ignored. For more information, see Policies.

    Args:
        directory_arn(str): The Amazon Resource Name (ARN) that is associated with the Directory. For more information, see arns.
        object_reference(Dict): Reference that identifies the object whose policies will be looked up.
        next_token(str, optional): The token to request the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of items to be retrieved in a single call. This is an approximate number. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.policy.init.lookup(
                ctx, directory_arn=value, object_reference=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.policy.init.lookup directory_arn=value, object_reference=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="lookup_policy",
        op_kwargs={
            "DirectoryArn": directory_arn,
            "ObjectReference": object_reference,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, organization_config_rule_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified organization config rule and all of its evaluation results from all member accounts in that organization.  Only a master account and a delegated administrator account can delete an organization config rule. When calling this API with a delegated administrator, you must ensure AWS Organizations ListDelegatedAdministrator permissions are added. AWS Config sets the state of a rule to DELETE_IN_PROGRESS until the deletion is complete. You cannot update a rule while it is in this state.

    Args:
        organization_config_rule_name(str): The name of organization config rule that you want to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.organization.config_rule.init.delete(
                ctx, organization_config_rule_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.organization.config_rule.init.delete organization_config_rule_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="delete_organization_config_rule",
        op_kwargs={"OrganizationConfigRuleName": organization_config_rule_name},
    )


async def describe_all(
    hub,
    ctx,
    organization_config_rule_names: List = None,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of organization config rules.   When you specify the limit and the next token, you receive a paginated response. Limit and next token are not applicable if you specify organization config rule names. It is only applicable, when you request all the organization config rules.

    Args:
        organization_config_rule_names(List, optional): The names of organization config rules for which you want details. If you do not specify any names, AWS Config returns details for all your organization config rules. Defaults to None.
        limit(int, optional): The maximum number of organization config rules returned on each page. If you do no specify a number, AWS Config uses the default. The default is 100. Defaults to None.
        next_token(str, optional): The nextToken string returned on a previous page that you use to get the next page of results in a paginated response. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.organization.config_rule.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.organization.config_rule.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="describe_organization_config_rules",
        op_kwargs={
            "OrganizationConfigRuleNames": organization_config_rule_names,
            "Limit": limit,
            "NextToken": next_token,
        },
    )


async def put(
    hub,
    ctx,
    organization_config_rule_name: str,
    organization_managed_rule_metadata: Dict = None,
    organization_custom_rule_metadata: Dict = None,
    excluded_accounts: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds or updates organization config rule for your entire organization evaluating whether your AWS resources comply with your desired configurations.  Only a master account and a delegated administrator can create or update an organization config rule. When calling this API with a delegated administrator, you must ensure AWS Organizations ListDelegatedAdministrator permissions are added.  This API enables organization service access through the EnableAWSServiceAccess action and creates a service linked role AWSServiceRoleForConfigMultiAccountSetup in the master or delegated administrator account of your organization. The service linked role is created only when the role does not exist in the caller account. AWS Config verifies the existence of role with GetRole action. To use this API with delegated administrator, register a delegated administrator by calling AWS Organization register-delegated-administrator for config-multiaccountsetup.amazonaws.com.  You can use this action to create both custom AWS Config rules and AWS managed Config rules. If you are adding a new custom AWS Config rule, you must first create AWS Lambda function in the master account or a delegated administrator that the rule invokes to evaluate your resources. When you use the PutOrganizationConfigRule action to add the rule to AWS Config, you must specify the Amazon Resource Name (ARN) that AWS Lambda assigns to the function. If you are adding an AWS managed Config rule, specify the rule's identifier for the RuleIdentifier key. The maximum number of organization config rules that AWS Config supports is 150 and 3 delegated administrator per organization.   Prerequisite: Ensure you call EnableAllFeatures API to enable all features in an organization. Specify either OrganizationCustomRuleMetadata or OrganizationManagedRuleMetadata.

    Args:
        organization_config_rule_name(str): The name that you assign to an organization config rule.
        organization_managed_rule_metadata(Dict, optional): An OrganizationManagedRuleMetadata object. . Defaults to None.
        organization_custom_rule_metadata(Dict, optional): An OrganizationCustomRuleMetadata object. Defaults to None.
        excluded_accounts(List, optional): A comma-separated list of accounts that you want to exclude from an organization config rule. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.organization.config_rule.init.put(
                ctx, organization_config_rule_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.organization.config_rule.init.put organization_config_rule_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="put_organization_config_rule",
        op_kwargs={
            "OrganizationConfigRuleName": organization_config_rule_name,
            "OrganizationManagedRuleMetadata": organization_managed_rule_metadata,
            "OrganizationCustomRuleMetadata": organization_custom_rule_metadata,
            "ExcludedAccounts": excluded_accounts,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    instance_id: str,
    contact_id: str,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Provides a list of analysis segments for a real-time analysis session.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance.
        contact_id(str): The identifier of the contact.
        max_results(int, optional): The maximimum number of results to return per page. Defaults to None.
        next_token(str, optional): The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect_contact_lens_realtime_contact_analysis_segment.list_all(
                ctx, instance_id=value, contact_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect_contact_lens_realtime_contact_analysis_segment.list_all instance_id=value, contact_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect-contact-lens",
        operation="list_realtime_contact_analysis_segments",
        op_kwargs={
            "InstanceId": instance_id,
            "ContactId": contact_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    task_id: str = None,
    violation_id: str = None,
    thing_name: str = None,
    start_time: str = None,
    end_time: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Lists mitigation actions executions for a Device Defender ML Detect Security Profile.

    Args:
        task_id(str, optional):  The unique identifier of the task. . Defaults to None.
        violation_id(str, optional):  The unique identifier of the violation. . Defaults to None.
        thing_name(str, optional):  The name of the thing whose mitigation actions are listed. . Defaults to None.
        start_time(str, optional):  A filter to limit results to those found after the specified time. You must specify either the startTime and endTime or the taskId, but not both. . Defaults to None.
        end_time(str, optional):  The end of the time period for which ML Detect mitigation actions executions are returned. . Defaults to None.
        max_results(int, optional):  The maximum number of results to return at one time. The default is 25. . Defaults to None.
        next_token(str, optional):  The token for the next set of results. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.detect_mitigation_action.execution.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.detect_mitigation_action.execution.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_detect_mitigation_actions_executions",
        op_kwargs={
            "taskId": task_id,
            "violationId": violation_id,
            "thingName": thing_name,
            "startTime": start_time,
            "endTime": end_time,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    cluster_name: str = None,
    tags: List = None,
    settings: List = None,
    configuration: Dict = None,
    capacity_providers: List = None,
    default_capacity_provider_strategy: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new Amazon ECS cluster. By default, your account receives a default cluster when you launch your first container instance. However, you can create your own cluster with a unique name with the CreateCluster action.  When you call the CreateCluster API operation, Amazon ECS attempts to create the Amazon ECS service-linked role for your account so that required resources in other Amazon Web Services services can be managed on your behalf. However, if the IAM user that makes the call does not have permissions to create the service-linked role, it is not created. For more information, see Using Service-Linked Roles for Amazon ECS in the Amazon Elastic Container Service Developer Guide.

    Args:
        cluster_name(str, optional): The name of your cluster. If you do not specify a name for your cluster, you create a cluster named default. Up to 255 letters (uppercase and lowercase), numbers, underscores, and hyphens are allowed. . Defaults to None.
        tags(List, optional): The metadata that you apply to the cluster to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define. The following basic restrictions apply to tags:   Maximum number of tags per resource - 50   For each resource, each tag key must be unique, and each tag key can have only one value.   Maximum key length - 128 Unicode characters in UTF-8   Maximum value length - 256 Unicode characters in UTF-8   If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.   Tag keys and values are case-sensitive.   Do not use aws:, AWS:, or any upper or lowercase combination of such as a prefix for either keys or values as it is reserved for Amazon Web Services use. You cannot edit or delete tag keys or values with this prefix. Tags with this prefix do not count against your tags per resource limit.  . Defaults to None.
        settings(List, optional): The setting to use when creating a cluster. This parameter is used to enable CloudWatch Container Insights for a cluster. If this value is specified, it will override the containerInsights value set with PutAccountSetting or PutAccountSettingDefault. Defaults to None.
        configuration(Dict, optional): The execute command configuration for the cluster. Defaults to None.
        capacity_providers(List, optional): The short name of one or more capacity providers to associate with the cluster. A capacity provider must be associated with a cluster before it can be included as part of the default capacity provider strategy of the cluster or used in a capacity provider strategy when calling the CreateService or RunTask actions. If specifying a capacity provider that uses an Auto Scaling group, the capacity provider must already be created and not already associated with another cluster. New Auto Scaling group capacity providers can be created with the CreateCapacityProvider API operation. To use a Fargate capacity provider, specify either the FARGATE or FARGATE_SPOT capacity providers. The Fargate capacity providers are available to all accounts and only need to be associated with a cluster to be used. The PutClusterCapacityProviders API operation is used to update the list of available capacity providers for a cluster after the cluster is created. Defaults to None.
        default_capacity_provider_strategy(List, optional): The capacity provider strategy to set as the default for the cluster. When a default capacity provider strategy is set for a cluster, when calling the RunTask or CreateService APIs wtih no capacity provider strategy or launch type specified, the default capacity provider strategy for the cluster is used. If a default capacity provider strategy is not defined for a cluster during creation, it can be defined later with the PutClusterCapacityProviders API operation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.cluster.init.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.cluster.init.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="create_cluster",
        op_kwargs={
            "clusterName": cluster_name,
            "tags": tags,
            "settings": settings,
            "configuration": configuration,
            "capacityProviders": capacity_providers,
            "defaultCapacityProviderStrategy": default_capacity_provider_strategy,
        },
    )


async def delete(hub, ctx, cluster: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified cluster. The cluster will transition to the INACTIVE state. Clusters with an INACTIVE status may remain discoverable in your account for a period of time. However, this behavior is subject to change in the future, so you should not rely on INACTIVE clusters persisting. You must deregister all container instances from this cluster before you may delete it. You can list the container instances in a cluster with ListContainerInstances and deregister them with DeregisterContainerInstance.

    Args:
        cluster(str): The short name or full Amazon Resource Name (ARN) of the cluster to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.cluster.init.delete(ctx, cluster=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.cluster.init.delete cluster=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="delete_cluster",
        op_kwargs={"cluster": cluster},
    )


async def describe_all(hub, ctx, clusters: List = None, include: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more of your clusters.

    Args:
        clusters(List, optional): A list of up to 100 cluster names or full cluster Amazon Resource Name (ARN) entries. If you do not specify a cluster, the default cluster is assumed. Defaults to None.
        include(List, optional): Whether to include additional information about the clusters in the response. If this field is omitted, this information isn't included. If ATTACHMENTS is specified, the attachments for the container instances or tasks within the cluster are included. If SETTINGS is specified, the settings for the cluster are included. If STATISTICS is specified, the task and service count is included, separated by launch type. If TAGS is specified, the metadata tags associated with the cluster are included. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.cluster.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.cluster.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="describe_clusters",
        op_kwargs={"clusters": clusters, "include": include},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of existing clusters.

    Args:
        next_token(str, optional): The nextToken value returned from a ListClusters request indicating that more results are available to fulfill the request and further calls will be needed. If maxResults was provided, it is possible the number of results to be fewer than maxResults.  This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes. . Defaults to None.
        max_results(int, optional): The maximum number of cluster results returned by ListClusters in paginated output. When this parameter is used, ListClusters only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListClusters request with the returned nextToken value. This value can be between 1 and 100. If this parameter is not used, then ListClusters returns up to 100 results and a nextToken value if applicable. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.cluster.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.cluster.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="list_clusters",
        op_kwargs={"nextToken": next_token, "maxResults": max_results},
    )


async def update(
    hub, ctx, cluster: str, settings: List = None, configuration: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the cluster.

    Args:
        cluster(str): The name of the cluster to modify the settings for.
        settings(List, optional): The cluster settings for your cluster. Defaults to None.
        configuration(Dict, optional): The execute command configuration for the cluster. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.cluster.init.update(ctx, cluster=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.cluster.init.update cluster=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="update_cluster",
        op_kwargs={
            "cluster": cluster,
            "settings": settings,
            "configuration": configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"import_": "import"}


async def copy(
    hub,
    ctx,
    name: str,
    source_image_id: str,
    source_region: str,
    description: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Copies the specified image from the specified Region to the current Region. For more information about copying images, see  Copy a Custom WorkSpaces Image.  In the China (Ningxia) Region, you can copy images only within the same Region. In the AWS GovCloud (US-West) Region, to copy images to and from other AWS Regions, contact AWS Support.   Before copying a shared image, be sure to verify that it has been shared from the correct AWS account. To determine if an image has been shared and to see the AWS account ID that owns an image, use the DescribeWorkSpaceImages and DescribeWorkspaceImagePermissions API operations.

    Args:
        name(str): The name of the image.
        description(str, optional): A description of the image. Defaults to None.
        source_image_id(str): The identifier of the source image.
        source_region(str): The identifier of the source Region.
        tags(List, optional): The tags for the image. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.workspace.image.init.copy(ctx, name=value, source_image_id=value, source_region=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.workspace.image.init.copy name=value, source_image_id=value, source_region=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="copy_workspace_image",
        op_kwargs={
            "Name": name,
            "Description": description,
            "SourceImageId": source_image_id,
            "SourceRegion": source_region,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, image_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified image from your account. To delete an image, you must first delete any bundles that are associated with the image and unshare the image if it is shared with other accounts.

    Args:
        image_id(str): The identifier of the image.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.workspace.image.init.delete(ctx, image_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.workspace.image.init.delete image_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="delete_workspace_image",
        op_kwargs={"ImageId": image_id},
    )


async def describe_all(
    hub,
    ctx,
    image_ids: List = None,
    image_type: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list that describes one or more specified images, if the image identifiers are provided. Otherwise, all images in the account are described.

    Args:
        image_ids(List, optional): The identifier of the image. Defaults to None.
        image_type(str, optional): The type (owned or shared) of the image. Defaults to None.
        next_token(str, optional): If you received a NextToken from a previous call that was paginated, provide this token to receive the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of items to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.workspace.image.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.workspace.image.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="describe_workspace_images",
        op_kwargs={
            "ImageIds": image_ids,
            "ImageType": image_type,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def import_(
    hub,
    ctx,
    ec2_image_id: str,
    ingestion_process: str,
    image_name: str,
    image_description: str,
    tags: List = None,
    applications: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Imports the specified Windows 10 Bring Your Own License (BYOL) image into Amazon WorkSpaces. The image must be an already licensed Amazon EC2 image that is in your AWS account, and you must own the image. For more information about creating BYOL images, see  Bring Your Own Windows Desktop Licenses.

    Args:
        ec2_image_id(str): The identifier of the EC2 image.
        ingestion_process(str): The ingestion process to be used when importing the image, depending on which protocol you want to use for your BYOL Workspace image, either PCoIP or WorkSpaces Streaming Protocol (WSP). To use WSP, specify a value that ends in _WSP. To use PCoIP, specify a value that does not end in _WSP.  For non-GPU-enabled bundles (bundles other than Graphics or GraphicsPro), specify BYOL_REGULAR or BYOL_REGULAR_WSP, depending on the protocol.
        image_name(str): The name of the WorkSpace image.
        image_description(str): The description of the WorkSpace image.
        tags(List, optional): The tags. Each WorkSpaces resource can have a maximum of 50 tags. Defaults to None.
        applications(List, optional): If specified, the version of Microsoft Office to subscribe to. Valid only for Windows 10 BYOL images. For more information about subscribing to Office for BYOL images, see  Bring Your Own Windows Desktop Licenses.  Although this parameter is an array, only one item is allowed at this time. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.workspace.image.init.import(ctx, ec2_image_id=value, ingestion_process=value, image_name=value, image_description=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.workspace.image.init.import ec2_image_id=value, ingestion_process=value, image_name=value, image_description=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="import_workspace_image",
        op_kwargs={
            "Ec2ImageId": ec2_image_id,
            "IngestionProcess": ingestion_process,
            "ImageName": image_name,
            "ImageDescription": image_description,
            "Tags": tags,
            "Applications": applications,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    role_arn: str,
    dataset_name: str = None,
    encryption_key_arn: str = None,
    encryption_mode: str = None,
    log_subscription: str = None,
    max_capacity: int = None,
    max_retries: int = None,
    outputs: List = None,
    data_catalog_outputs: List = None,
    database_outputs: List = None,
    project_name: str = None,
    recipe_reference: Dict = None,
    tags: Dict = None,
    timeout: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new job to transform input data, using steps defined in an existing Glue DataBrew recipe

    Args:
        dataset_name(str, optional): The name of the dataset that this job processes. Defaults to None.
        encryption_key_arn(str, optional): The Amazon Resource Name (ARN) of an encryption key that is used to protect the job. Defaults to None.
        encryption_mode(str, optional): The encryption mode for the job, which can be one of the following:    SSE-KMS - Server-side encryption with keys managed by KMS.    SSE-S3 - Server-side encryption with keys managed by Amazon S3.  . Defaults to None.
        name(str): A unique name for the job. Valid characters are alphanumeric (A-Z, a-z, 0-9), hyphen (-), period (.), and space.
        log_subscription(str, optional): Enables or disables Amazon CloudWatch logging for the job. If logging is enabled, CloudWatch writes one log stream for each job run. Defaults to None.
        max_capacity(int, optional): The maximum number of nodes that DataBrew can consume when the job processes data. Defaults to None.
        max_retries(int, optional): The maximum number of times to retry the job after a job run fails. Defaults to None.
        outputs(List, optional): One or more artifacts that represent the output from running the job. Defaults to None.
        data_catalog_outputs(List, optional): One or more artifacts that represent the Glue Data Catalog output from running the job. Defaults to None.
        database_outputs(List, optional): Represents a list of JDBC database output objects which defines the output destination for a DataBrew recipe job to write to. . Defaults to None.
        project_name(str, optional): Either the name of an existing project, or a combination of a recipe and a dataset to associate with the recipe. Defaults to None.
        recipe_reference(Dict, optional): Represents the name and version of a DataBrew recipe. Defaults to None.
        role_arn(str): The Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role to be assumed when DataBrew runs the job.
        tags(Dict, optional): Metadata tags to apply to this job. Defaults to None.
        timeout(int, optional): The job's timeout in minutes. A job that attempts to run longer than this timeout period ends with a status of TIMEOUT. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.recipe.job.create(ctx, name=value, role_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.recipe.job.create name=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="create_recipe_job",
        op_kwargs={
            "DatasetName": dataset_name,
            "EncryptionKeyArn": encryption_key_arn,
            "EncryptionMode": encryption_mode,
            "Name": name,
            "LogSubscription": log_subscription,
            "MaxCapacity": max_capacity,
            "MaxRetries": max_retries,
            "Outputs": outputs,
            "DataCatalogOutputs": data_catalog_outputs,
            "DatabaseOutputs": database_outputs,
            "ProjectName": project_name,
            "RecipeReference": recipe_reference,
            "RoleArn": role_arn,
            "Tags": tags,
            "Timeout": timeout,
        },
    )


async def update(
    hub,
    ctx,
    name: str,
    role_arn: str,
    encryption_key_arn: str = None,
    encryption_mode: str = None,
    log_subscription: str = None,
    max_capacity: int = None,
    max_retries: int = None,
    outputs: List = None,
    data_catalog_outputs: List = None,
    database_outputs: List = None,
    timeout: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the definition of an existing DataBrew recipe job.

    Args:
        encryption_key_arn(str, optional): The Amazon Resource Name (ARN) of an encryption key that is used to protect the job. Defaults to None.
        encryption_mode(str, optional): The encryption mode for the job, which can be one of the following:    SSE-KMS - Server-side encryption with keys managed by KMS.    SSE-S3 - Server-side encryption with keys managed by Amazon S3.  . Defaults to None.
        name(str): The name of the job to update.
        log_subscription(str, optional): Enables or disables Amazon CloudWatch logging for the job. If logging is enabled, CloudWatch writes one log stream for each job run. Defaults to None.
        max_capacity(int, optional): The maximum number of nodes that DataBrew can consume when the job processes data. Defaults to None.
        max_retries(int, optional): The maximum number of times to retry the job after a job run fails. Defaults to None.
        outputs(List, optional): One or more artifacts that represent the output from running the job. . Defaults to None.
        data_catalog_outputs(List, optional): One or more artifacts that represent the Glue Data Catalog output from running the job. Defaults to None.
        database_outputs(List, optional): Represents a list of JDBC database output objects which defines the output destination for a DataBrew recipe job to write into. Defaults to None.
        role_arn(str): The Amazon Resource Name (ARN) of the Identity and Access Management (IAM) role to be assumed when DataBrew runs the job.
        timeout(int, optional): The job's timeout in minutes. A job that attempts to run longer than this timeout period ends with a status of TIMEOUT. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.databrew.recipe.job.update(ctx, name=value, role_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.databrew.recipe.job.update name=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="databrew",
        operation="update_recipe_job",
        op_kwargs={
            "EncryptionKeyArn": encryption_key_arn,
            "EncryptionMode": encryption_mode,
            "Name": name,
            "LogSubscription": log_subscription,
            "MaxCapacity": max_capacity,
            "MaxRetries": max_retries,
            "Outputs": outputs,
            "DataCatalogOutputs": data_catalog_outputs,
            "DatabaseOutputs": database_outputs,
            "RoleArn": role_arn,
            "Timeout": timeout,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Get detail data for the AWS Proton pipeline service role.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.account_setting.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.account_setting.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="proton", operation="get_account_settings", op_kwargs={}
    )


async def update_multiple(hub, ctx, pipeline_service_role_arn: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Update the AWS Proton pipeline service account settings.

    Args:
        pipeline_service_role_arn(str, optional): The Amazon Resource Name (ARN) of the AWS Proton pipeline service role. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.account_setting.update_multiple(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.account_setting.update_multiple
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="update_account_settings",
        op_kwargs={"pipelineServiceRoleArn": pipeline_service_role_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, container_recipe_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the policy for a container recipe.

    Args:
        container_recipe_arn(str): The Amazon Resource Name (ARN) of the container recipe for the policy being requested.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.container_recipe.policy.get(
                ctx, container_recipe_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.container_recipe.policy.get container_recipe_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="get_container_recipe_policy",
        op_kwargs={"containerRecipeArn": container_recipe_arn},
    )


async def put(hub, ctx, container_recipe_arn: str, policy: str) -> Dict:
    r"""
    **Autogenerated function**

    Applies a policy to a container image. We recommend that you call the RAM API CreateResourceShare (https://docs.aws.amazon.com/ram/latest/APIReference/API_CreateResourceShare.html) to share resources. If you call the Image Builder API PutContainerImagePolicy, you must also call the RAM API PromoteResourceShareCreatedFromPolicy (https://docs.aws.amazon.com/ram/latest/APIReference/API_PromoteResourceShareCreatedFromPolicy.html) in order for the resource to be visible to all principals with whom the resource is shared.

    Args:
        container_recipe_arn(str): The Amazon Resource Name (ARN) of the container recipe that this policy should be applied to.
        policy(str): The policy to apply to the container recipe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.container_recipe.policy.put(
                ctx, container_recipe_arn=value, policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.container_recipe.policy.put container_recipe_arn=value, policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="put_container_recipe_policy",
        op_kwargs={"containerRecipeArn": container_recipe_arn, "policy": policy},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    stream_id: str,
    files: List,
    role_arn: str,
    description: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a stream for delivering one or more large files in chunks over MQTT. A stream transports data bytes in chunks or blocks packaged as MQTT messages from a source like S3. You can have one or more files associated with a stream.

    Args:
        stream_id(str): The stream ID.
        description(str, optional): A description of the stream. Defaults to None.
        files(List): The files to stream.
        role_arn(str): An IAM role that allows the IoT service principal assumes to access your S3 files.
        tags(List, optional): Metadata which can be used to manage streams. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.stream.create(
                ctx, stream_id=value, files=value, role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.stream.create stream_id=value, files=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="create_stream",
        op_kwargs={
            "streamId": stream_id,
            "description": description,
            "files": files,
            "roleArn": role_arn,
            "tags": tags,
        },
    )


async def delete(hub, ctx, stream_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a stream.

    Args:
        stream_id(str): The stream ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.stream.delete(ctx, stream_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.stream.delete stream_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="delete_stream",
        op_kwargs={"streamId": stream_id},
    )


async def describe(hub, ctx, stream_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a stream.

    Args:
        stream_id(str): The stream ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.stream.describe(ctx, stream_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.stream.describe stream_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="describe_stream",
        op_kwargs={"streamId": stream_id},
    )


async def list_all(
    hub,
    ctx,
    max_results: int = None,
    next_token: str = None,
    ascending_order: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all of the streams in your AWS account.

    Args:
        max_results(int, optional): The maximum number of results to return at a time. Defaults to None.
        next_token(str, optional): A token used to get the next set of results. Defaults to None.
        ascending_order(bool, optional): Set to true to return the list of streams in ascending order. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.stream.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.stream.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_streams",
        op_kwargs={
            "maxResults": max_results,
            "nextToken": next_token,
            "ascendingOrder": ascending_order,
        },
    )


async def update(
    hub,
    ctx,
    stream_id: str,
    description: str = None,
    files: List = None,
    role_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing stream. The stream version will be incremented by one.

    Args:
        stream_id(str): The stream ID.
        description(str, optional): The description of the stream. Defaults to None.
        files(List, optional): The files associated with the stream. Defaults to None.
        role_arn(str, optional): An IAM role that allows the IoT service principal assumes to access your S3 files. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.stream.update(ctx, stream_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.stream.update stream_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="update_stream",
        op_kwargs={
            "streamId": stream_id,
            "description": description,
            "files": files,
            "roleArn": role_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def contains(hub, ctx, text: str, language_code: str) -> Dict:
    r"""
    **Autogenerated function**

    Analyzes input text for the presence of personally identifiable information (PII) and returns the labels of identified PII entity types such as name, address, bank account number, or phone number.

    Args:
        text(str): Creates a new document classification request to analyze a single document in real-time, returning personally identifiable information (PII) entity labels.
        language_code(str): The language of the input documents.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.pii_entity.init.contains(
                ctx, text=value, language_code=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.pii_entity.init.contains text=value, language_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="contains_pii_entities",
        op_kwargs={"Text": text, "LanguageCode": language_code},
    )


async def detect(hub, ctx, text: str, language_code: str) -> Dict:
    r"""
    **Autogenerated function**

    Inspects the input text for entities that contain personally identifiable information (PII) and returns information about them.

    Args:
        text(str): A UTF-8 text string. Each string must contain fewer that 5,000 bytes of UTF-8 encoded characters.
        language_code(str): The language of the input documents.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.pii_entity.init.detect(
                ctx, text=value, language_code=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.pii_entity.init.detect text=value, language_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="detect_pii_entities",
        op_kwargs={"Text": text, "LanguageCode": language_code},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the properties associated with an entities detection job. Use this operation to get the status of a detection job.

    Args:
        job_id(str): The identifier that Amazon Comprehend generated for the job. The operation returns this identifier in its response.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.entity.detection_job.describe(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.entity.detection_job.describe job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="describe_entities_detection_job",
        op_kwargs={"JobId": job_id},
    )


async def list_all(
    hub, ctx, filter_: Dict = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of the entity detection jobs that you have submitted.

    Args:
        filter_(Dict, optional): Filters the jobs that are returned. You can filter jobs on their name, status, or the date and time that they were submitted. You can only set one filter at a time. Defaults to None.
        next_token(str, optional): Identifies the next page of results to return. Defaults to None.
        max_results(int, optional): The maximum number of results to return in each page. The default is 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.entity.detection_job.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.entity.detection_job.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="list_entities_detection_jobs",
        op_kwargs={
            "Filter": filter_,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def start(
    hub,
    ctx,
    input_data_config: Dict,
    output_data_config: Dict,
    data_access_role_arn: str,
    language_code: str,
    job_name: str = None,
    entity_recognizer_arn: str = None,
    client_request_token: str = None,
    volume_kms_key_id: str = None,
    vpc_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts an asynchronous entity detection job for a collection of documents. Use the operation to track the status of a job. This API can be used for either standard entity detection or custom entity recognition. In order to be used for custom entity recognition, the optional EntityRecognizerArn must be used in order to provide access to the recognizer being used to detect the custom entity.

    Args:
        input_data_config(Dict): Specifies the format and location of the input data for the job.
        output_data_config(Dict): Specifies where to send the output files.
        data_access_role_arn(str): The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role that grants Amazon Comprehend read access to your input data. For more information, see https://docs.aws.amazon.com/comprehend/latest/dg/access-control-managing-permissions.html#auth-role-permissions.
        job_name(str, optional): The identifier of the job. Defaults to None.
        entity_recognizer_arn(str, optional): The Amazon Resource Name (ARN) that identifies the specific entity recognizer to be used by the StartEntitiesDetectionJob. This ARN is optional and is only used for a custom entity recognition job. Defaults to None.
        language_code(str): The language of the input documents. All documents must be in the same language. You can specify any of the languages supported by Amazon Comprehend. If custom entities recognition is used, this parameter is ignored and the language used for training the model is used instead.
        client_request_token(str, optional): A unique identifier for the request. If you don't set the client request token, Amazon Comprehend generates one. Defaults to None.
        volume_kms_key_id(str, optional): ID for the AWS Key Management Service (KMS) key that Amazon Comprehend uses to encrypt data on the storage volume attached to the ML compute instance(s) that process the analysis job. The VolumeKmsKeyId can be either of the following formats:   KMS Key ID: "1234abcd-12ab-34cd-56ef-1234567890ab"    Amazon Resource Name (ARN) of a KMS Key: "arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"   . Defaults to None.
        vpc_config(Dict, optional): Configuration parameters for an optional private Virtual Private Cloud (VPC) containing the resources you are using for your entity detection job. For more information, see Amazon VPC. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.entity.detection_job.start(
                ctx,
                input_data_config=value,
                output_data_config=value,
                data_access_role_arn=value,
                language_code=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.entity.detection_job.start input_data_config=value, output_data_config=value, data_access_role_arn=value, language_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="start_entities_detection_job",
        op_kwargs={
            "InputDataConfig": input_data_config,
            "OutputDataConfig": output_data_config,
            "DataAccessRoleArn": data_access_role_arn,
            "JobName": job_name,
            "EntityRecognizerArn": entity_recognizer_arn,
            "LanguageCode": language_code,
            "ClientRequestToken": client_request_token,
            "VolumeKmsKeyId": volume_kms_key_id,
            "VpcConfig": vpc_config,
        },
    )


async def stop(hub, ctx, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops an entities detection job in progress. If the job state is IN_PROGRESS the job is marked for termination and put into the STOP_REQUESTED state. If the job completes before it can be stopped, it is put into the COMPLETED state; otherwise the job is stopped and put into the STOPPED state. If the job is in the COMPLETED or FAILED state when you call the StopDominantLanguageDetectionJob operation, the operation returns a 400 Internal Request Exception.  When a job is stopped, any documents already processed are written to the output location.

    Args:
        job_id(str): The identifier of the entities detection job to stop.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.entity.detection_job.stop(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.entity.detection_job.stop job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="stop_entities_detection_job",
        op_kwargs={"JobId": job_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    inference_scheduler_name: str,
    next_token: str = None,
    max_results: int = None,
    data_start_time_after: str = None,
    data_end_time_before: str = None,
    status: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Lists all inference executions that have been performed by the specified inference scheduler.

    Args:
        next_token(str, optional): An opaque pagination token indicating where to continue the listing of inference executions. Defaults to None.
        max_results(int, optional): Specifies the maximum number of inference executions to list. . Defaults to None.
        inference_scheduler_name(str): The name of the inference scheduler for the inference execution listed. .
        data_start_time_after(str, optional): The time reference in the inferenced dataset after which Amazon Lookout for Equipment started the inference execution. . Defaults to None.
        data_end_time_before(str, optional): The time reference in the inferenced dataset before which Amazon Lookout for Equipment stopped the inference execution. . Defaults to None.
        status(str, optional): The status of the inference execution. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutequipment.inference.execution.list_all(
                ctx, inference_scheduler_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutequipment.inference.execution.list_all inference_scheduler_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutequipment",
        operation="list_inference_executions",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "InferenceSchedulerName": inference_scheduler_name,
            "DataStartTimeAfter": data_start_time_after,
            "DataEndTimeBefore": data_end_time_before,
            "Status": status,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def add(hub, ctx, finding_arns: List, attributes: List) -> Dict:
    r"""
    **Autogenerated function**

    Assigns attributes (key and value pairs) to the findings that are specified by the ARNs of the findings.

    Args:
        finding_arns(List): The ARNs that specify the findings that you want to assign attributes to.
        attributes(List): The array of attributes that you want to assign to specified findings.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.inspector.attribute.to_finding.add(
                ctx, finding_arns=value, attributes=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.inspector.attribute.to_finding.add finding_arns=value, attributes=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="inspector",
        operation="add_attributes_to_findings",
        op_kwargs={"findingArns": finding_arns, "attributes": attributes},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    application_name: str,
    template_name: str,
    solution_stack_name: str = None,
    platform_arn: str = None,
    source_configuration: Dict = None,
    environment_id: str = None,
    description: str = None,
    option_settings: List = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an AWS Elastic Beanstalk configuration template, associated with a specific Elastic Beanstalk application. You define application configuration settings in a configuration template. You can then use the configuration template to deploy different versions of the application with the same configuration settings. Templates aren't associated with any environment. The EnvironmentName response element is always null. Related Topics    DescribeConfigurationOptions     DescribeConfigurationSettings     ListAvailableSolutionStacks

    Args:
        application_name(str): The name of the Elastic Beanstalk application to associate with this configuration template.
        template_name(str): The name of the configuration template. Constraint: This name must be unique per application.
        solution_stack_name(str, optional): The name of an Elastic Beanstalk solution stack (platform version) that this configuration uses. For example, 64bit Amazon Linux 2013.09 running Tomcat 7 Java 7. A solution stack specifies the operating system, runtime, and application server for a configuration template. It also determines the set of configuration options as well as the possible and default values. For more information, see Supported Platforms in the AWS Elastic Beanstalk Developer Guide. You must specify SolutionStackName if you don't specify PlatformArn, EnvironmentId, or SourceConfiguration. Use the  ListAvailableSolutionStacks  API to obtain a list of available solution stacks. Defaults to None.
        platform_arn(str, optional): The Amazon Resource Name (ARN) of the custom platform. For more information, see  Custom Platforms in the AWS Elastic Beanstalk Developer Guide.  If you specify PlatformArn, then don't specify SolutionStackName. . Defaults to None.
        source_configuration(Dict, optional): An Elastic Beanstalk configuration template to base this one on. If specified, Elastic Beanstalk uses the configuration values from the specified configuration template to create a new configuration. Values specified in OptionSettings override any values obtained from the SourceConfiguration. You must specify SourceConfiguration if you don't specify PlatformArn, EnvironmentId, or SolutionStackName. Constraint: If both solution stack name and source configuration are specified, the solution stack of the source configuration template must match the specified solution stack name. Defaults to None.
        environment_id(str, optional): The ID of an environment whose settings you want to use to create the configuration template. You must specify EnvironmentId if you don't specify PlatformArn, SolutionStackName, or SourceConfiguration. Defaults to None.
        description(str, optional): An optional description for this configuration. Defaults to None.
        option_settings(List, optional): Option values for the Elastic Beanstalk configuration, such as the instance type. If specified, these values override the values obtained from the solution stack or the source configuration template. For a complete list of Elastic Beanstalk configuration options, see Option Values in the AWS Elastic Beanstalk Developer Guide. Defaults to None.
        tags(List, optional): Specifies the tags applied to the configuration template. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.configuration.template.create(
                ctx, application_name=value, template_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.configuration.template.create application_name=value, template_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="create_configuration_template",
        op_kwargs={
            "ApplicationName": application_name,
            "TemplateName": template_name,
            "SolutionStackName": solution_stack_name,
            "PlatformArn": platform_arn,
            "SourceConfiguration": source_configuration,
            "EnvironmentId": environment_id,
            "Description": description,
            "OptionSettings": option_settings,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, application_name: str, template_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified configuration template.  When you launch an environment using a configuration template, the environment gets a copy of the template. You can delete or modify the environment's copy of the template without affecting the running environment.

    Args:
        application_name(str): The name of the application to delete the configuration template from.
        template_name(str): The name of the configuration template to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.configuration.template.delete(
                ctx, application_name=value, template_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.configuration.template.delete application_name=value, template_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="delete_configuration_template",
        op_kwargs={"ApplicationName": application_name, "TemplateName": template_name},
    )


async def update(
    hub,
    ctx,
    application_name: str,
    template_name: str,
    description: str = None,
    option_settings: List = None,
    options_to_remove: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified configuration template to have the specified properties or configuration option values.  If a property (for example, ApplicationName) is not provided, its value remains unchanged. To clear such properties, specify an empty string.  Related Topics    DescribeConfigurationOptions

    Args:
        application_name(str): The name of the application associated with the configuration template to update.  If no application is found with this name, UpdateConfigurationTemplate returns an InvalidParameterValue error. .
        template_name(str): The name of the configuration template to update.  If no configuration template is found with this name, UpdateConfigurationTemplate returns an InvalidParameterValue error. .
        description(str, optional): A new description for the configuration. Defaults to None.
        option_settings(List, optional): A list of configuration option settings to update with the new specified option value. Defaults to None.
        options_to_remove(List, optional): A list of configuration options to remove from the configuration set.  Constraint: You can remove only UserDefined configuration options. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.configuration.template.update(
                ctx, application_name=value, template_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.configuration.template.update application_name=value, template_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="update_configuration_template",
        op_kwargs={
            "ApplicationName": application_name,
            "TemplateName": template_name,
            "Description": description,
            "OptionSettings": option_settings,
            "OptionsToRemove": options_to_remove,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def remove(hub, ctx, resource_name: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes the tags identified by the TagKeys list from the named resource. A tag is a key-value pair where the key and value are case-sensitive. You can use tags to categorize and track all your ElastiCache resources, with the exception of global replication group. When you add or remove tags on replication groups, those actions will be replicated to all nodes in the replication group. For more information, see Resource-level permissions.

    Args:
        resource_name(str): The Amazon Resource Name (ARN) of the resource from which you want the tags removed, for example arn:aws:elasticache:us-west-2:0123456789:cluster:myCluster or arn:aws:elasticache:us-west-2:0123456789:snapshot:mySnapshot. For more information about ARNs, see Amazon Resource Names (ARNs) and AWS Service Namespaces.
        tag_keys(List): A list of TagKeys identifying the tags you want removed from the named resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticache.tags.from_resource.remove(
                ctx, resource_name=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticache.tags.from_resource.remove resource_name=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticache",
        operation="remove_tags_from_resource",
        op_kwargs={"ResourceName": resource_name, "TagKeys": tag_keys},
    )
